==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridActionStripContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebGridActionStripContentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionStripContentDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionStripContentDescriptionMetadata.a == null) {
                WebGridActionStripContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionStripContentDescriptionMetadata.c(WebGridActionStripContentDescriptionMetadata.a);
            }
            if (a.j(WebGridActionStripContentDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridActionStripContentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionStripContent");
            a.item("__tagNameWC", "String:igc-grid-action-strip-content");
            a.item("__manageCollectionInMarkup", "Boolean");
        }
        static d(a) {
            WebGridActionStripContentDescriptionMetadata.b(a);
            a.z("WebGridActionStripContent", WebGridActionStripContentDescriptionMetadata.a);
        }
    }
    WebGridActionStripContentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionStripContentDescriptionMetadata, 'WebGridActionStripContentDescriptionMetadata');
    WebGridActionStripContentDescriptionMetadata.a = null;
    return WebGridActionStripContentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridActionStripContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebGridActionStripContentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionStripContentDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionStripContentDescriptionMetadata.a == null) {
                WebGridActionStripContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionStripContentDescriptionMetadata.c(WebGridActionStripContentDescriptionMetadata.a);
            }
            if (a.k(WebGridActionStripContentDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridActionStripContentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionStripContent");
            a.item("__tagNameWC", "String:igc-grid-action-strip-content");
            a.item("__manageCollectionInMarkup", "Boolean");
        }
        static d(a) {
            WebGridActionStripContentDescriptionMetadata.b(a);
            a.ab("WebGridActionStripContent", WebGridActionStripContentDescriptionMetadata.a);
        }
    }
    WebGridActionStripContentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionStripContentDescriptionMetadata, 'WebGridActionStripContentDescriptionMetadata');
    WebGridActionStripContentDescriptionMetadata.a = null;
    return WebGridActionStripContentDescriptionMetadata;
})();
